﻿-- ********************************************************************************
-- Broker Statistics
-- A Data Broker display for combat statistics.
-- By: Shenton
--
-- DropDownMenu.lua
-- ********************************************************************************

local A = _G["DataBrokerStatisticsGlobal"];

-- Lua globals
local supper = string.upper;

-- Generate the dropdown menu
local info = {};
local function DropDownMenu(self, level)
    if ( not level ) then return; end

    if ( level == 1 ) then
        -- Menu title
        info.isTitle = 1;
        info.hasArrow = nil;
        info.text = A.L["Broker Statistics"];
        info.notCheckable = 1;
        UIDropDownMenu_AddButton(info, level);

        -- Set options
        info.keepShownOnClick = 1;
        info.hasArrow = 1;
        info.isTitle = nil;
        info.disabled = nil;

        -- Built in stats menu
        info.text = A.ddmAlignRight..A.L["Built in Stats"];
        info.value = "BUILT_IN_STATS";
        UIDropDownMenu_AddButton(info, level);

        -- Custom stats menu
        if ( A:GotCustom() ) then
            info.text = A.ddmAlignRight..A.L["Custom Stats"];
            info.value = "CUSTOM_STATS";
            UIDropDownMenu_AddButton(info, level);
        end

        -- Blank separator
        info.text = "";
        info.disabled = 1;
        info.notCheckable = 1;
        info.hasArrow = nil;
        UIDropDownMenu_AddButton(info, level);

        -- Options menu
        info.text = A.ddmAlignRight..A.L["Options"];
		info.value = "OPTIONS";
        info.disabled = nil;
		info.hasArrow = 1;
		UIDropDownMenu_AddButton(info, level);

        -- Close
        info.text = A.L["Close"];
        info.hasArrow = nil;
        info.func = function() CloseDropDownMenus(); end;
        UIDropDownMenu_AddButton(info, level);
    elseif (level == 2 ) then
        if ( UIDROPDOWNMENU_MENU_VALUE == "OPTIONS" ) then
            -- Options menu title
            info.isTitle = 1;
            info.hasArrow = nil;
            info.text = A.L["Options"];
            info.notCheckable = 1;
            UIDropDownMenu_AddButton(info, level);

            -- Open configuration panel
            info.text = A.ddmAlignRight..A.L["Configuration Panel"];
            info.isTitle = nil;
            info.disabled = nil;
            info.hasArrow = nil;
            info.func = function() A:OpenConfigPanel(); end;
            UIDropDownMenu_AddButton(info, level);

            -- Pause
            info.text = A.L["Pause"];
            info.notCheckable = nil;
            info.checked = function() return A.paused; end;
            info.func = function() A:PauseToggle(); end;
            UIDropDownMenu_AddButton(info, level);

            -- Refresh rate menu
            info.text = A.ddmAlignRight..A.L["Refresh Rate"];
            info.hasArrow = 1;
            info.notCheckable = 1;
            info.value = "REFRESH_RATE";
            UIDropDownMenu_AddButton(info, level);
        elseif ( UIDROPDOWNMENU_MENU_VALUE == "BUILT_IN_STATS" ) then
            -- Built in stats menu title
            info.isTitle = 1;
            info.hasArrow = nil;
            info.text = A.L["Built in Stats"];
            info.notCheckable = 1;
            UIDropDownMenu_AddButton(info, level);

            -- Misc cat
            info.text = A.ddmAlignRight..A.L["Miscellaneous"];
            info.isTitle = nil;
            info.disabled = nil;
            info.value = "BUILT_IN_STATS_MISC";
            info.hasArrow = 1
            info.notCheckable = 1;
            UIDropDownMenu_AddButton(info, level);

            -- Tank cat
            info.text = A.ddmAlignRight..A.L["Tank"];
            info.value = "BUILT_IN_STATS_TANK";
            UIDropDownMenu_AddButton(info, level);

            -- Melee cat
            info.text = A.ddmAlignRight..A.L["Melee"];
            info.value = "BUILT_IN_STATS_MELEE";
            UIDropDownMenu_AddButton(info, level);

            -- Ranged cat
            info.text = A.ddmAlignRight..A.L["Ranged"];
            info.value = "BUILT_IN_STATS_RANGED";
            UIDropDownMenu_AddButton(info, level);

            -- Spell cat
            info.text = A.ddmAlignRight..A.L["Spell"];
            info.value = "BUILT_IN_STATS_SPELL";
            UIDropDownMenu_AddButton(info, level);
        elseif ( UIDROPDOWNMENU_MENU_VALUE == "CUSTOM_STATS" ) then
            -- Custom stats menu title
            info.isTitle = 1;
            info.hasArrow = nil;
            info.text = A.L["Custom Stats"];
            info.notCheckable = 1;
            UIDropDownMenu_AddButton(info, level);

            -- Options
            info.notCheckable = nil;
            info.hasArrow = nil;
            info.isTitle = nil;
            info.disabled = nil;

            for k in A:PairsByKeys(A.db.global.custom) do
                info.text = k;
                info.checked = function()
                    if ( A.db.profile.custom[A.playerSpec][k] ) then
                        return A.db.profile.custom[A.playerSpec][k].enabled;
                    else
                        return nil;
                    end
                end;
                info.func = function()
                    if ( A.db.profile.custom[A.playerSpec][k] ) then
                        A.db.profile.custom[A.playerSpec][k].enabled = not A.db.profile.custom[A.playerSpec][k].enabled;
                        A.db.profile.custom[A.playerSpec][k].dbObject = self.dbObject;
                    else
                        A.db.profile.custom[A.playerSpec][k] =
                        {
                            enabled = 1,
                            dbObject = self.dbObject
                        };
                    end

                    A:RefreshConfig();
                end;
                UIDropDownMenu_AddButton(info, level);
            end
        end
    elseif (level == 3 ) then
        if ( UIDROPDOWNMENU_MENU_VALUE == "BUILT_IN_STATS_MISC" ) then
            -- Misc menu title
            info.isTitle = 1;
            info.hasArrow = nil;
            info.text = A.L["Miscellaneous"];
            info.notCheckable = 1;
            UIDropDownMenu_AddButton(info, level);
        elseif ( UIDROPDOWNMENU_MENU_VALUE == "BUILT_IN_STATS_TANK" ) then
            -- Tank menu title
            info.isTitle = 1;
            info.hasArrow = nil;
            info.text = A.L["Tank"];
            info.notCheckable = 1;
            UIDropDownMenu_AddButton(info, level);
        elseif ( UIDROPDOWNMENU_MENU_VALUE == "BUILT_IN_STATS_MELEE" ) then
            -- Melee menu title
            info.isTitle = 1;
            info.hasArrow = nil;
            info.text = A.L["Melee"];
            info.notCheckable = 1;
            UIDropDownMenu_AddButton(info, level);
        elseif ( UIDROPDOWNMENU_MENU_VALUE == "BUILT_IN_STATS_RANGED" ) then
            -- Ranged menu title
            info.isTitle = 1;
            info.hasArrow = nil;
            info.text = A.L["Ranged"];
            info.notCheckable = 1;
            UIDropDownMenu_AddButton(info, level);
        elseif ( UIDROPDOWNMENU_MENU_VALUE == "BUILT_IN_STATS_SPELL" ) then
            -- Spell menu title
            info.isTitle = 1;
            info.hasArrow = nil;
            info.text = A.L["Spell"];
            info.notCheckable = 1;
            UIDropDownMenu_AddButton(info, level);
        elseif ( UIDROPDOWNMENU_MENU_VALUE == "REFRESH_RATE" ) then
            -- Refresh rate title
            info.isTitle = 1;
            info.hasArrow = nil;
            info.text = A.L["Refresh Rate"];
            info.notCheckable = 1;
            UIDropDownMenu_AddButton(info, level);

            -- Options
            info.isTitle = nil;
            info.disabled = nil;
            info.notCheckable = 1;

            -- Rate
            info.text = A.ddmAlignRight..A.L["Rate: %.1f"]:format(A.db.profile.time);
            info.func = nil;
            UIDropDownMenu_AddButton(info, level);

            -- Rate +
            info.text = A.ddmAlignRight..A.L["Rate +"];
            info.func = function()
                if ( A.db.profile.time < 5 ) then
                    A.db.profile.time = A.db.profile.time + 0.1;
                    A:RefreshTimer();
                    DropDownList3Button2:SetText(A.ddmAlignRight..A.L["Rate: %.1f"]:format(A.db.profile.time));
                end
            end;
            UIDropDownMenu_AddButton(info, level);

            -- Rate -
            info.text = A.ddmAlignRight..A.L["Rate -"];
            info.func = function()
                if ( A.db.profile.time > 0.1 ) then
                    A.db.profile.time = A.db.profile.time - 0.1;
                    A:RefreshTimer();
                    DropDownList3Button2:SetText(A.ddmAlignRight..A.L["Rate: %.1f"]:format(A.db.profile.time));
                end
            end;
            UIDropDownMenu_AddButton(info, level);
        end

        -- Options
        info.notCheckable = nil;
        info.hasArrow = nil;
        info.isTitle = nil;
        info.disabled = nil;

        for k,v in A:PairsByKeys(A.builtInStats) do
            local menuValue = "BUILT_IN_STATS_"..supper(v.type);

            if ( UIDROPDOWNMENU_MENU_VALUE == menuValue ) then
                info.text = k;
                info.checked = function()
                    if ( A.db.profile.builtInStats[A.playerSpec][k] ) then
                        return A.db.profile.builtInStats[A.playerSpec][k].enabled;
                    else
                        return nil;
                    end
                end;
                info.func = function()
                    if ( A.db.profile.builtInStats[A.playerSpec][k] ) then
                        A.db.profile.builtInStats[A.playerSpec][k].enabled = not A.db.profile.builtInStats[A.playerSpec][k].enabled;
                        A.db.profile.builtInStats[A.playerSpec][k].dbObject = self.dbObject;
                        print(self.dbObject)
                    else
                        A.db.profile.builtInStats[A.playerSpec][k] =
                        {
                            enabled = 1,
                            dbObject = self.dbObject
                        };
                    end

                    A:RefreshConfig();
                end;
                UIDropDownMenu_AddButton(info, level);
            end
        end
    end
end

-- Call the dropdown menu
function A:DropDownMenu(callFrame, dbObject)
    if ( not A.dropDownMenuFrame.initialize ) then A.dropDownMenuFrame.initialize = DropDownMenu; end

    A.dropDownMenuFrame.dbObject = dbObject;

    --ToggleDropDownMenu(1, nil, A.dropDownMenuFrame, callFrame:GetName(), 0, 0);
    ToggleDropDownMenu(1, nil, A.dropDownMenuFrame, callFrame, 0, 0);
    GameTooltip:Hide();
end
